# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vector_search.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='vector_search.proto',
  package='searchvector',
  syntax='proto3',
  serialized_pb=_b('\n\x13vector_search.proto\x12\x0csearchvector\"2\n\rSearchRequest\x12\x0e\n\x06vector\x18\x01 \x01(\x0c\x12\x11\n\tcandidate\x18\x02 \x01(\x05\"1\n\x0bSearchReply\x12\x10\n\x08vector_d\x18\x01 \x01(\x0c\x12\x10\n\x08vector_i\x18\x02 \x01(\x0c\x32R\n\x06Search\x12H\n\x0cSearchVector\x12\x1b.searchvector.SearchRequest\x1a\x19.searchvector.SearchReply\"\x00\x42\x38\n\x1aio.stylelens.search.vectorB\x11SearchVectorProtoP\x01\xa2\x02\x04STYLb\x06proto3')
)




_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='searchvector.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='searchvector.SearchRequest.vector', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='searchvector.SearchRequest.candidate', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=87,
)


_SEARCHREPLY = _descriptor.Descriptor(
  name='SearchReply',
  full_name='searchvector.SearchReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector_d', full_name='searchvector.SearchReply.vector_d', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vector_i', full_name='searchvector.SearchReply.vector_i', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=138,
)

DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['SearchReply'] = _SEARCHREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHREQUEST,
  __module__ = 'vector_search_pb2'
  # @@protoc_insertion_point(class_scope:searchvector.SearchRequest)
  ))
_sym_db.RegisterMessage(SearchRequest)

SearchReply = _reflection.GeneratedProtocolMessageType('SearchReply', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHREPLY,
  __module__ = 'vector_search_pb2'
  # @@protoc_insertion_point(class_scope:searchvector.SearchReply)
  ))
_sym_db.RegisterMessage(SearchReply)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\032io.stylelens.search.vectorB\021SearchVectorProtoP\001\242\002\004STYL'))

_SEARCH = _descriptor.ServiceDescriptor(
  name='Search',
  full_name='searchvector.Search',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=140,
  serialized_end=222,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchVector',
    full_name='searchvector.Search.SearchVector',
    index=0,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_SEARCHREPLY,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SEARCH)

DESCRIPTOR.services_by_name['Search'] = _SEARCH

# @@protoc_insertion_point(module_scope)



# coding: utf-8

from __future__ import absolute_import

import os
import grpc
import numpy as np

from .grpc import vector_search_pb2
from .grpc import vector_search_pb2_grpc

VECTOR_SEARCH_HOST = os.environ['VECTOR_SEARCH_HOST']
VECTOR_SEARCH_PORT = os.environ['VECTOR_SEARCH_PORT']

class VectorSearch(object):
  def __init__(self):
    print('init')

  def search(self, vector, limit=10):
    channel = grpc.insecure_channel(VECTOR_SEARCH_HOST + ':' + VECTOR_SEARCH_PORT)
    stub = vector_search_pb2_grpc.SearchStub(channel)
    # v = np.asarray(vector, dtype=np.float32)
    # results = stub.SearchVector(vector_search_pb2.SearchRequest(vector=v.tobytes(),
    #                                                             candidate=limit))
    results = stub.SearchVector(vector_search_pb2.SearchRequest(vector=vector,
                                                                candidate=limit))
    return results

